# 0.3.0

 - Several metrics are computed at the same time.
 - Horizontal bar plot is produced for the metric values.
 - The process covariance is effectively fixed to its measurement covariance.

# 0.2.4

 - Using `kinematic-tracker==19.3.0` -- the version which is not yanked.

# 0.2.0

 - First version published in PyPI.


# 0.1.0

 - Ensure the scalar part of the quaternions is greater than or equal zero.
 - Using `kinematic-tracker==19.0.0` (first version class-resolved).
 - Set the window title.
 - Report the name of the metric and score value in the axis title.
 - Switch between association metrics with keystroke `m`.
 - The report coordinate mode is switchable with keystroke `c`.
 - The range is changed from `-10..10` to `-5..15`.
 - Compute and report to the text in the figure.
 - Add some boilerplate code for a matplotlib driven GUI app.
 - Add dependencies.
 - Start the Project.

